<?php

/**
 * Plugin Name: DGH Plugin
 * Description: DGH plugin.
 * Version: 0.0.1
 * Author: I+ Srl
 * Author URI: http://www.i-piu.it
 * Text Domain: 
 * Domain Path: 
 * Network: 
 * License: I+ Srl EULA
*/

include "utils/aggrlogin.php"; // Itself included utils/restcalls.php.
include "utils/ui.php";

/*
    The custom post types introduces by the Tender plugin. These custom post
    types are defined admin-side via a set of specialized input fields used for
    their creation, and client-side by extensions to the Wordpress rendering
    algorithm that account for the presence of the implied extra fields.
    
    - An ARTICLE is very similar to a regular Wordpress post. Its only estension
      is a 'condition' field that describes a condition affecting a Tender
      end user. The administrator can set the condition, which will be clearly
      displayed to the user before the actual Wordpress post content.
    - A VIDEO resource extends a post with a 'condition' and an URL to a video
      file. The administrator can set the condition, which will be clearly
      displayed to the user before the actual content, and upload/reference
      a video file, which will be shown to the user right after the condition
      and before the actual Wordpress blog post text.
    - A FACTOID resource extends a post with a 'condition', an URL to an image,
      file, and a pair of text fragments called 'factoid text' and 'factoid suggestion'.
      The administrator can set the condition, which will be clearly
      displayed to the user at the top of the page; after the condition, the user
      is shown the 'factoid text', then the selected image, and finally the
      'factoid suggestion'. A FACTOID resource suppresses the standard Wordpress
      blog post text, and instead relies only on 'factoid text' and 'factoid suggestion'
      to present textual information to the user.
    
    Extension to the admin user interface and to the end user pages is implemented
    by hooking into HTML rendering events.
    
    Extension to the database model of a blog post are implemented using
    Wordpress metakeys.
*/
define("TENDERPLUGIN_POSTTYPE_VIDEO", "tender_video");
define("TENDERPLUGIN_POSTTYPE_FACTOID", "tender_factoid");
define("TENDERPLUGIN_POSTTYPE_ARTICLE", "tender_article");

/*
    The HTML names of the input fields required for the editing of a custom
    post. Each of these HTML input fields is backed into the Wordpress database
    by a metakey property.
*/

// Condition is required by all three custom post types, and represent the
// medical condition that affects a Tender user.
// This HTML input field is backed by the metakey TENDERPLUGIN_METAKEY_CONDITION.
define("TENDERPLUGIN_INPUTNAME_CONDITION", "tenderplugin_inputname_condition");

// The following field is relevant only for TENDERPLUGIN_POSTTYPE_VIDEO and is
// the URL of a video file.
// This HTML input field is backed by the metakey TENDERPLUGIN_METAKEY_VIDEOVIDEO.
define("TENDERPLUGIN_INPUTNAME_VIDEOVIDEO", "tenderplugin_inputname_videovideo");

// The following field is relevant only for TENDERPLUGIN_POSTTYPE_FACTOID and is
// the URL of an image file.
// This HTML input field is backed by the metakey TENDERPLUGIN_METAKEY_FACTOIDIMAGE.
define("TENDERPLUGIN_INPUTNAME_FACTOIDIMAGE", "tenderplugin_inputname_factoidimage");

// The following field is relevant only for TENDERPLUGIN_POSTTYPE_FACTOID and is
// a factoid introductory text (something that may follow a rhetorical question
// such as 'Did you know that...'.
// This HTML input field is backed by the metakey TENDERPLUGIN_METAKEY_FACTOIDTEXT.
define("TENDERPLUGIN_INPUTNAME_FACTOIDTEXT", "tenderplugin_inputname_factoidtext");

// The following field is relevant only for TENDERPLUGIN_POSTTYPE_FACTOID and is
// a suggestion regarding the factoid described in the introductory text.
// This HTML input field is backed by the metakey TENDERPLUGIN_METAKEY_FACTOIDSUGGESTION.
define("TENDERPLUGIN_INPUTNAME_FACTOIDSUGGESTION", "tenderplugin_inputname_factoidsuggestion");

/*
    The names of the metakeys required to back the extended features of the
    custom post types introduced by Tender plugin. Each of these metakeys
    corresponds to an input field used by the administrator when editing the
    custom post type, and is also taken into account by the extended rendering
    algorithm to present the end user with the additional information carried
    by the Tender posts.
*/

// This metakey is backed by the HTML input field TENDERPLUGIN_INPUTNAME_CONDITION.
define("TENDERPLUGIN_METAKEY_CONDITION", "tenderplugin_metakey_condition");

// This metakey is backed by the HTML input field TENDERPLUGIN_INPUTNAME_VIDEOVIDEO.
define("TENDERPLUGIN_METAKEY_VIDEOVIDEO", "tenderplugin_metakey_videovideo");

// This metakey is backed by the HTML input field TENDERPLUGIN_INPUTNAME_FACTOIDIMAGE.
define("TENDERPLUGIN_METAKEY_FACTOIDIMAGE", "tenderplugin_metakey_factoidimage");

// This metakey is backed by the HTML input field TENDERPLUGIN_INPUTNAME_FACTOIDTEXT.
define("TENDERPLUGIN_METAKEY_FACTOIDTEXT", "tenderplugin_metakey_factoidtext");

// This metakey is backed by the HTML input field TENDERPLUGIN_INPUTNAME_FACTOIDSUGGESTION.
define("TENDERPLUGIN_METAKEY_FACTOIDSUGGESTION", "tenderplugin_metakey_factoidsuggestion");

// This metakey is stores the aggregator id of the educational object backing a post of custom type.
define("TENDERPLUGIN_METAKEY_EDUCATIONALID", "tenderplugin_metakey_educationalid");

define("TENDERPLUGIN_METAKEY_AGGRENTRYPOINT", "tenderplugin_metakey_aggrentrypoint");

// Used to store a custom slug.
define("TENDERPLUGIN_METAKEY_CUSTOMSLUG", "tenderplugin_metakey_customslug");

/*
    The 'init' hook is called whenever the plugin is invoked. Tender plugin taps
    into this hook to create the custom post types. And to request the inclusion
    of some Javascript that is required for the implementation of the media
    upload administrator interface.
*/
add_action('init', 'tenderplugin_init');
function tenderplugin_init() {

    error_log("init() called.");

    // Registers a VIDEO custom post type.
    register_post_type(TENDERPLUGIN_POSTTYPE_VIDEO,
        array(
            'labels' => array(
                'name' => __('Videos'),
                'singular_name' => __('Video')),
            'public' => true,
            'has_archive' => true
        )
    );
  
    // Registers a FACTOID custom post type.
    register_post_type(TENDERPLUGIN_POSTTYPE_FACTOID,
        array(
            // Factoids do not use Wordpress blog post text, and instead
            // rely on two custom text fields (associated to metakeys
            // TENDERPLUGIN_INPUTNAME_FACTOIDTEXT and TENDERPLUGIN_INPUTNAME_FACTOIDSUGGESTION)
            // to present data to the user. The default is for a post to have
            // a title and a body; the following setting removes the body.
            'supports' => array("title"),
            
            // NOTE: In case you wish to also remove the title, you may consider
            // to specify something along the lines of:
            // 'supports' => array(),
            // But unfortunately this fails to remove anything, probably because
            // the empty array is interpreted by PHP as 'not specified' and
            // register_post_type goes back to displaying both title and text,
            // which is the default.
            
            // If you really want to remove the title you can specify an array
            // that contains a dummy string.
            //'supports' => array("Layla, you've got me on my knees."),
            
            'labels' => array(
                'name' => __('Factoids'),
                'singular_name' => __('Factoid')),
            'public' => true,
            'has_archive' => true
        )
    );
  
    /*
        In place of the 'supports' directive, also something like the following
        may work to remove editor and title from the post:
      
            remove_post_type_support('tender_factoid', 'editor');
            remove_post_type_support('tender_factoid', 'title');
    */
  
    register_post_type(TENDERPLUGIN_POSTTYPE_ARTICLE,
        array(
            'labels' => array(
                'name' => __('Articles'),
                'singular_name' => __('Article')),
            'public' => true,
            'has_archive' => true
        )
    );
    
    // Functions tenderplugin_mbc_videovideo and tenderplugin_mbc_factoidimage
    // emit HTML code that relies on the presence of an external script. The
    // script is in the 'js' subdirectory of the plugin. The plugin can request
    // Wordpress to reference the script from the generated page by calling
    // wp_enqueue_script.
    wp_enqueue_script('tenderplugin_script', plugins_url() . "/dghplugin/js/tenderplugin.js", array(), '1.0.0', true);
    
    wp_enqueue_style('tenderplugin_main_style', plugins_url("/dghplugin/css/main.css"));
    wp_add_inline_style('tenderplugin_main_style',
        ".login h1 a {
            background-image: url(" . plugins_url("dghplugin/gfx/dgh-edu-icon.png") . ");
            padding-bottom: 30px;
        }
        ");
    
    /*
    $user = wp_get_current_user();
    if (get_user_meta($user->ID, TENDERPLUGIN_METAKEY_AGGRENTRYPOINT, true) == "") {
        if (get_user_meta($user->ID, TENDERPLUGIN_METAKEY_AGGRPASSWORD, true) != "") {
            update_user_meta($user->ID, TENDERPLUGIN_METAKEY_AGGRENTRYPOINT, "166.111.83.253:8080");
        }
    }
    
    if (get_user_meta($user->ID, TENDERPLUGIN_METAKEY_AGGRPASSWORD, true) != "") {
        global $aggregator_server;
        $aggregator_server = get_user_meta($user->ID, TENDERPLUGIN_METAKEY_AGGRENTRYPOINT, true);
    }
    */
    
    global $aggregator_server;
    $aggregator_server = get_option(TENDERPLUGIN_METAKEY_AGGRENTRYPOINT, "http://166.111.83.253:8080/aggregator/service");
}

/*
    Hooking into 'add_meta_boxes' enables customization of the admin interface
    for custom post types. Each additional information is stored in the database
    and associated to a metakey and displayed to the admin in an input field.
    Each one of these input field is displayed into a metabox, an user interface
    component managed by Wordpress. Metaboxes are added by calling add_meta_box.
    
    The HTML content of a metabox is customized via a callback function passed to
    add_meta_box.
*/
add_action('add_meta_boxes', 'tenderplugin_add_meta_boxes');
function tenderplugin_add_meta_boxes() {

    // All Tender custom post types need the condition. Let us gather
    // them in array...
	$post_types = array(
        get_post_type_object(TENDERPLUGIN_POSTTYPE_VIDEO),
        get_post_type_object(TENDERPLUGIN_POSTTYPE_FACTOID),
        get_post_type_object(TENDERPLUGIN_POSTTYPE_ARTICLE));

    // ...and iterate on them.
	foreach ($post_types as $post_type) {
		add_meta_box(
			'tenderplugin_sectionid_condition',
			__( 'Specify condition for this \'' . $post_type->labels->singular_name . '\':', 'tenderplugin_textdomain' ),
			'tenderplugin_mbc_condition',
			$post_type->name
		);
	}
    
    // Only the 'video' custom post type needs the video upload.
    add_meta_box(
        'tenderplugin_sectionid_videovideo',
        'Fact Video',
        'tenderplugin_mbc_videovideo',
        TENDERPLUGIN_POSTTYPE_VIDEO
    );
    
    // Only the 'factoid' custom post type needs the image upload.
    add_meta_box(
        'tenderplugin_sectionid_factoidimage',
        'Fact Image',
        'tenderplugin_mbc_factoidimage',
        TENDERPLUGIN_POSTTYPE_FACTOID
    );
    
    // Only the 'factoid' custom post type needs the introductory text.
    add_meta_box(
        'tenderplugin_sectionid_factoidtext',
        'Fact',
        'tenderplugin_mbc_factoidtext',
        TENDERPLUGIN_POSTTYPE_FACTOID
    );
    
    // Only the 'factoid' custom post type needs the suggestion.
    add_meta_box(
        'tenderplugin_sectionid_factoidsuggestion',
        'Suggestion',
        'tenderplugin_mbc_factoidsuggestion',
        TENDERPLUGIN_POSTTYPE_FACTOID
    );
}

/*
    Metabox callback functions are registered with 'add_meta_box' and invoked
    by Wordpress when it needs to generate the HTML code of a metabox.
    The 'mbc' component of the name stands for 'MetaBox Callback'.
*/

/*
    Callback function that defines the HTML content of a condition metabox.
    Note that this function also fetches data from the appropriate metakeys to
    render HTML input fields containing the current value stored into the database.
    Applies to all custom post types (video, factoid and article).
*/
function tenderplugin_mbc_condition($post) {

    $value = get_post_meta($post->ID, TENDERPLUGIN_METAKEY_CONDITION, true);

    //global $aggregator_server;
    //echo "<b>$aggregator_server</b>";
    
    ?> <label for="<?=TENDERPLUGIN_INPUTNAME_CONDITION?>">Condition</label> <?php
    conditions_select(null, TENDERPLUGIN_INPUTNAME_CONDITION, $value);
}

/*
    Callback function that defines the HTML content of a video upload metabox.
    Note that this function also fetches data from the appropriate metakeys to
    render HTML input fields containing the current value stored into the database.
    Applies to the 'video' custom post type.
*/
function tenderplugin_mbc_videovideo($post) {

    $value = get_post_meta($post->ID, TENDERPLUGIN_METAKEY_VIDEOVIDEO, true);

    echo "<input type='text' id='tenderplugin_inputid_videovideo' name='" . TENDERPLUGIN_INPUTNAME_VIDEOVIDEO . "' value='$value'><input type='button' value='Pick video...' onclick='showVideoPicker();return false;'>";
}

/*
    Callback function that defines the HTML content of a image upload metabox.
    Note that this function also fetches data from the appropriate metakeys to
    render HTML input fields containing the current value stored into the database.
    Applies to the 'factoid' custom post type.
*/
function tenderplugin_mbc_factoidimage($post) {

    $value = get_post_meta($post->ID, TENDERPLUGIN_METAKEY_FACTOIDIMAGE, true);

    echo "<input type='text' id='tenderplugin_inputid_factoidimage' name='" . TENDERPLUGIN_INPUTNAME_FACTOIDIMAGE . "' value='$value'><input type='button' value='Pick image...' onclick='showImagePicker();return false;'>";
}

/*
    Callback function that defines the HTML content of the introductory text metabox.
    Note that this function also fetches data from the appropriate metakeys to
    render HTML input fields containing the current value stored into the database.
    Applies to the 'factoid' custom post type.
*/
function tenderplugin_mbc_factoidtext($post) {

    $value = get_post_meta($post->ID, TENDERPLUGIN_METAKEY_FACTOIDTEXT, true);

    wp_editor($value, TENDERPLUGIN_INPUTNAME_FACTOIDTEXT, $settings = array());
}

/*
    Callback function that defines the HTML content of the suggestion metabox.
    Note that this function also fetches data from the appropriate metakeys to
    render HTML input fields containing the current value stored into the database.
    Applies to the 'factoid' custom post type.
*/
function tenderplugin_mbc_factoidsuggestion($post) {

    $value = get_post_meta($post->ID, TENDERPLUGIN_METAKEY_FACTOIDSUGGESTION, true);

    wp_editor($value, TENDERPLUGIN_INPUTNAME_FACTOIDSUGGESTION, $settings = array());
}

/*
    Hooking into 'save_post' allows us to extract data from the custom input fields
    and store it into the database under the appropriate metakeys. This 'store'
    operation is in effect the opposite of the 'fetch' operations implemented
    by the tenderplugin_mbc_* callback functions.
*/
//add_action('save_post', 'tenderplugin_updatemeta');
//function tenderplugin_updatemeta($post_id) {
    /*
    if ($_POST['post_type'] == TENDERPLUGIN_POSTTYPE_VIDEO ||
        $_POST['post_type'] == TENDERPLUGIN_POSTTYPE_FACTOID ||
        $_POST['post_type'] == TENDERPLUGIN_POSTTYPE_ARTICLE) {
        update_post_meta($post_id, TENDERPLUGIN_METAKEY_CONDITION, $_POST[TENDERPLUGIN_INPUTNAME_CONDITION]);
    }
    
    if ($_POST['post_type'] == TENDERPLUGIN_POSTTYPE_VIDEO) {
        update_post_meta($post_id, TENDERPLUGIN_METAKEY_VIDEOVIDEO, $_POST[TENDERPLUGIN_INPUTNAME_VIDEOVIDEO]);
    }
    
    if ($_POST['post_type'] == TENDERPLUGIN_POSTTYPE_FACTOID) {
        update_post_meta($post_id, TENDERPLUGIN_METAKEY_FACTOIDIMAGE, $_POST[TENDERPLUGIN_INPUTNAME_FACTOIDIMAGE]);
        update_post_meta($post_id, TENDERPLUGIN_METAKEY_FACTOIDTEXT, $_POST[TENDERPLUGIN_INPUTNAME_FACTOIDTEXT]);
        update_post_meta($post_id, TENDERPLUGIN_METAKEY_FACTOIDSUGGESTION, $_POST[TENDERPLUGIN_INPUTNAME_FACTOIDSUGGESTION]);
    }
    */
//}

/*
    We can define multiple callback functions for a single hook.

    Hooking into 'save_post' is also used to notify the aggregator when a novel
    educational resource is posted.
*/
add_action('save_post', 'tenderplugin_notifyaggregator');
function tenderplugin_notifyaggregator( $post_id ) {
    if ($post_id == "" or !isset($post_id)) {
        return;
    }

    //print_r($post_id);
    //die();


	$text = "";

    if ($_POST['post_type'] == TENDERPLUGIN_POSTTYPE_VIDEO ||
        $_POST['post_type'] == TENDERPLUGIN_POSTTYPE_FACTOID ||
        $_POST['post_type'] == TENDERPLUGIN_POSTTYPE_ARTICLE) {
        update_post_meta($post_id, TENDERPLUGIN_METAKEY_CONDITION, $_POST[TENDERPLUGIN_INPUTNAME_CONDITION]);
    }
    
    if ($_POST['post_type'] == TENDERPLUGIN_POSTTYPE_VIDEO) {
        update_post_meta($post_id, TENDERPLUGIN_METAKEY_VIDEOVIDEO, $_POST[TENDERPLUGIN_INPUTNAME_VIDEOVIDEO]);
    }
    
    if ($_POST['post_type'] == TENDERPLUGIN_POSTTYPE_FACTOID) {
		$text = $_POST[TENDERPLUGIN_INPUTNAME_FACTOIDTEXT];
        update_post_meta($post_id, TENDERPLUGIN_METAKEY_FACTOIDIMAGE, $_POST[TENDERPLUGIN_INPUTNAME_FACTOIDIMAGE]);
        update_post_meta($post_id, TENDERPLUGIN_METAKEY_FACTOIDTEXT, $_POST[TENDERPLUGIN_INPUTNAME_FACTOIDTEXT]);
        update_post_meta($post_id, TENDERPLUGIN_METAKEY_FACTOIDSUGGESTION, $_POST[TENDERPLUGIN_INPUTNAME_FACTOIDSUGGESTION]);
    }




	





	if ( wp_is_post_revision( $post_id ) )
		return;

	$post_title = get_the_title( $post_id );
	//$post_url = get_permalink( $post_id );
    global $post;
    $condition = get_post_meta($post->ID, TENDERPLUGIN_METAKEY_CONDITION, true);
    
    if ($condition == "") {
        return;
    }
    
    
    
    
    $pt = $post->post_type;





    //$slug = $post->post_name; // !!!FLAWED!!!
    $slug = get_post_meta($post->ID, TENDERPLUGIN_METAKEY_CUSTOMSLUG, true);
    if ($slug == "") {
        $slug = sanitize_title($post_title);
        update_post_meta($post->ID, TENDERPLUGIN_METAKEY_CUSTOMSLUG, $slug);
    }
        
    if ($pt == 'tender_video') {
        $kind = 'videos';
        $k = 'video';
    }
        
    if ($pt == 'tender_factoid') {
        $kind = 'factoids';
        $k = 'factoid';
    }
        
    if ($pt == 'tender_article') {
        $kind = 'articles';
        $k = 'article';
    }
        
    //$description = "A post has been updated for $condition/$kind";
	$description = $_POST[TENDERPLUGIN_INPUTNAME_FACTOIDSUGGESTION];
    $post_url = "https://webkeepwell.ddns.net/$condition/$kind/$slug/";
    
    
    
    
    
    
    
    $result = tenderplugin_aggregator_login();
    
    
    
    
    
    
    
    
    
    //session_start();
    //if (isset($_SESSION['login_info'])) {
    //    $result = $_SESSION['login_info'];
    //}
    //else {
    //    $result = aggregator_login("a@a.it", "aa");
    //    $_SESSION['login_info'] = $result;
    //}
    
    
    
    
    
    
    $educ = array(
        "name" => $post_title,
        "description" => $description,
        "urlOfContent" => $post_url,
		"text" => $text,
        "type" => $k);
    
    
    
    
    
    
    
    
    /*
    $subject = "Debugging aggregator nofitication";
	$message = "Post updated for $condition/$kind:\n\n";
	$message .= "\n\n" . $post_title . ": " . $post_url;
    $message .= "\n\nPermalink: http://www.smartkira.com/druxaps5/$condition/$kind/$slug/";
	wp_mail( 'dario.damico@gmail.com', $subject, $message );
    */
    
    $aggr_id = get_post_meta($post_id, TENDERPLUGIN_METAKEY_EDUCATIONALID, true);
    
    //echo $aggr_id;
    if ($aggr_id == "") {
        $aggr_id = aggregator_addeducational($result['Authorized-By'], $condition, $educ);
        //die($aggr_id . "sdadsdads");
        update_post_meta($post_id, TENDERPLUGIN_METAKEY_EDUCATIONALID, $aggr_id);
    }
    else {
        $educ["id"] = $aggr_id;
        aggregator_updateeducational($result['Authorized-By'], $condition, $educ);
    }
    //die($aggr_id);
    aggregator_logout($result['Authorized-By']);
    
    
    
    
    
    /*
	// If this is just a revision, don't send the email.
	if ( wp_is_post_revision( $post_id ) )
		return;

	$post_title = get_the_title( $post_id );
	$post_url = get_permalink( $post_id );

    global $post;
    $condition = get_post_meta($post->ID, 'tenderplugin_condition_meta_key', true);
    $pt = $post->post_type;
    $slug = $post->post_name;
    
    if ($pt == 'tender_video')
        $kind = 'videos';
        
    if ($pt == 'tender_factoid')
        $kind = 'factoids';
        
    if ($pt == 'tender_article')
        $kind = 'articles';
    
    $subject = "A post has been updated for $condition/$kind";
    
	$message = "Post updated for $condition/$kind:\n\n";
	$message .= "\n\n" . $post_title . ": " . $post_url;
    $message .= "\n\nPermalink: http://www.smartkira.com/druxaps5/$condition/$kind/$slug/";
    
	wp_mail( 'dario.damico@gmail.com', $subject, $message );
    */
}

/*
    Hooking into 'the_content' enables customization of how a post is displayed
    to the end user.
*/
add_action('the_content', 'tenderplugin_the_content');
function tenderplugin_the_content() {
    global $post;
    $pt = $post->post_type;
    $condition = get_post_meta($post->ID, TENDERPLUGIN_METAKEY_CONDITION, true);
    $reqUri = $_SERVER['REQUEST_URI'];
    
    //if ($condition != '') {
    if (strpos($reqUri, '/videos/') !== FALSE || strpos($reqUri, '/factoids/') !== FALSE || strpos($reqUri, '/articles/') !== FALSE) {
        if (strpos($reqUri, '/' . $condition . '/') !== false) {
            // OK :-)
        }
        else {
            die("Condition mismatch! Request URI '$reqUri' points to a '$condition' resource.");
        }
    }
    
    if ($condition != '') {
        if ($pt == TENDERPLUGIN_POSTTYPE_VIDEO || $pt == TENDERPLUGIN_POSTTYPE_FACTOID || $pt == TENDERPLUGIN_POSTTYPE_ARTICLE) {
            $imgPath =  plugins_url() . "/dghplugin/gfx/" . $condition . ".png";
            echo "<div style=\"text-align: center;\"><img src=\"$imgPath\" style=\"height: 3em; vertical-align: middle;\"><span style=\"\">Condition: <b>" . $condition . "</b></span></div>";
        }
    }
    
    if ($pt == TENDERPLUGIN_POSTTYPE_VIDEO) {
        echo "<video style=\"margin-left: auto; margin-right: auto; width: 320px;\" width=\"320\" height=\"240\" controls>";
        echo "    <source src=\"" . get_post_meta($post->ID, TENDERPLUGIN_METAKEY_VIDEOVIDEO, true) . "\">";
        echo "    Your browser does not support the video tag.";
        echo "</video>";
    }
    
    if ($pt == TENDERPLUGIN_POSTTYPE_FACTOID) {
        echo "<h1>Did you know?</h1>";
        echo get_post_meta($post->ID, TENDERPLUGIN_METAKEY_FACTOIDTEXT, true);
        echo "<img src=\"" . get_post_meta($post->ID, TENDERPLUGIN_METAKEY_FACTOIDIMAGE, true) . "\">";
        echo "<h1>Know it!</h1>";
        echo get_post_meta($post->ID, TENDERPLUGIN_METAKEY_FACTOIDSUGGESTION, true);
    }
    else {
        remove_action('the_content', 'tenderplugin_the_content');
        $content = apply_filters( 'the_content', get_the_content() );
        $content = str_replace( ']]>', ']]&gt;', $content );
        echo $content;
        add_action( 'the_content', 'tenderplugin_the_content' );
    }
    
    global $current_user;
    get_currentuserinfo();

    $aggr_user = $current_user->user_email;
    //echo "<b>[[[$aggr_user]]]</b>";
}

add_action('user_register', 'tenderplugin_registration_save');
function tenderplugin_registration_save($user_id) {
    $aggr_user = $_POST["user_email"];
    $aggr_password = substr(sha1(rand()), 0, 8);
    update_user_meta($user_id, TENDERPLUGIN_METAKEY_AGGRPASSWORD, $aggr_password);
    aggregator_register($aggr_user, $aggr_password);
    
    //print_r($_POST);
    //die(":-/");
    //global $current_user;
    //get_currentuserinfo();

    //$aggr_user = $current_user->user_email;
    //die(":: " . $aggr_user);
    //$aggr_password = substr(sha1(rand()), 0, 8);
    //update_user_meta($user_id, TENDERPLUGIN_METAKEY_AGGRPASSWORD, $aggr_password);
    //aggregator_register();
}

add_action('admin_menu', 'tenderplugin_custompages');
function tenderplugin_custompages() {
    // edit_posts
    add_menu_page('Aggregator settings', 'Aggregator settings', 'manage_options', 'dghplugin/aggrsettings.php', '', plugins_url('dghplugin/gfx/aggrsettings.png'));
	add_menu_page('Manage Goals', 'Manage Goals', 'manage_options', 'dghplugin/goals.php', '', plugins_url('dghplugin/gfx/goal_ico_web.png'));
    add_menu_page('Manage Reminders', 'Manage Reminders', 'manage_options', 'dghplugin/reminders.php', '', plugins_url('dghplugin/gfx/reminder_ico_web.png'));
    add_menu_page('Manage Conditions', 'Manage Conditions', 'manage_options', 'dghplugin/conditions.php', '', plugins_url('dghplugin/gfx/condition_ico_web.png'));
    add_menu_page('Manage Symptoms', 'Manage Symptoms', 'manage_options', 'dghplugin/symptoms.php', '', plugins_url('dghplugin/gfx/symptom_ico.png'));
    add_menu_page('Manage Workouts', 'Manage Workouts', 'manage_options', 'dghplugin/workouts.php', '', plugins_url('dghplugin/gfx/workout_ico.png'));
}

?>
